@@ -26,5 +26,5 @@ $my_graph->set(
 ) 
 or warn $my_graph->error;
 
-$my_graph->plot(\@data);
+$my_graph->plot(\@data) or die $my_graph->error;
 save_chart($my_graph, 'sample11');
